@@ -13,14 +13,14 @@ extern "C" SEXP isolines_impl(SEXP x, SEXP y, SEXP z, SEXP value);
 extern "C" SEXP separate_polygons(SEXP x, SEXP y, SEXP id);
 
 // From testthat
-extern "C" SEXP run_testthat_tests();
+extern "C" SEXP run_testthat_tests(SEXP use_xml_sxp);
 
 static const R_CallMethodDef CallEntries[] = {
   {"clip_lines_impl_c", (DL_FUNC) &clip_lines_impl, 9},
   {"isobands_impl_c", (DL_FUNC) &isobands_impl, 5},
   {"isolines_impl_c", (DL_FUNC) &isolines_impl, 4},
   {"separate_polygons_c", (DL_FUNC) &separate_polygons, 3},
-  {"run_testthat_tests", (DL_FUNC) &run_testthat_tests, 0},
+  {"run_testthat_tests", (DL_FUNC) &run_testthat_tests, 1},
   {NULL, NULL, 0}
 };
 
